@@ -32,7 +32,7 @@ class McCabeMetric(MetricBase):
     def process_token(self, tok):
         """Increment number of decision points in function."""
         #if tok and tok.text in mccabe_keywords:
-        if (tok[0][0] == b'Keyword') and tok[1] in mccabe_keywords:
+        if (tok[0][0] == 'Keyword') and tok[1] in mccabe_keywords:
             self.metrics['mccabe'] += 1
 
     def display_header(self):
